Config

Struct Config 

pub struct Config {
Show 17 fields pub linear_problem: bool, pub transient: bool, pub dynamics: bool, pub constant_tangent: bool, pub control: Control, pub gravity: Option<FnTime>, pub axisymmetric: bool, pub plane_stress: bool, pub thickness: f64, pub total_stress: bool, pub initialization: Init, pub param_fluids: Option<ParamFluids>, pub n_integ_point: HashMap<CellAttribute, usize>, pub sym_jacobian: bool, pub sym_pos_def_jacobian: bool, pub lin_sol_genie: Genie, pub lin_sol_params: LinSolParams,
}
Holds configuration parameters

Fields

linear_problem: bool

Linear problem

transient: bool

Transient analysis (with first time derivative of primary variables)

dynamics: bool

Dynamics analysis (with second time derivative of primary variables)

constant_tangent: bool

Pseudo-Newton method with constant-tangent operator

control: Control

Holds control variables for the (pseudo) time integration over the simulation period

gravity: Option<FnTime>

Gravity acceleration (positive variable)

Note: The corresponding acceleration vector will be directed against y in 2D or z in 3D; e.g., a_gravity = {0, -GRAVITY}ᵀ in 2D or a_gravity = {0, 0, -GRAVITY}ᵀ in 3D.

Example:

const GRAVITY: f64 = 10.0;
config.gravity = Some(|_| GRAVITY);
axisymmetric: bool

Axisymmetric problem represented in 2D (instead of plane-strain)

plane_stress: bool

Plane-stress problem instead of plane-strain iff 2D

thickness: f64

Thickness for plane-stress or 1.0 otherwise

total_stress: bool

Total stress analysis (instead of effective stresses)

initialization: Init

Option to initialize stress state

param_fluids: Option<ParamFluids>

Parameters for fluids

n_integ_point: HashMap<CellAttribute, usize>

Number of integration points

sym_jacobian: bool

The Jacobian (stiffness matrix) is symmetric

sym_pos_def_jacobian: bool

The Jacobian (stiffness matrix) is symmetric and positive definite

lin_sol_genie: Genie

Linear solver type

lin_sol_params: LinSolParams

Parameters for the sparse solver

Implementations

Source

impl Config

pub fn new() -> Self

Allocates a new instance

pub fn validate(&self, ndim: usize) -> Option<String>

Validates all data

Returns a message with the inconsistent data, or returns None if everything is all right.

pub fn validate_or_panic(&self, ndim: usize, verbose: bool)

Validate data or panics

pub fn initial_overburden_stress(&self) -> f64

Returns the initial overburden stress (negative means compression)

pub fn integ_point_data(&self, cell: &Cell) -> Result<IntegPointData, StrError>

Returns the integration (Gauss) points data